//    Austin is a program for updating projects kept in XML files.
//    Copyright (C) 2000  Joseph Gregorio
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef AUSTIN_TASK_H
#define AUSTIN_TASK_H

#include <vector>
#include <string>
#include <dom/DOM_Element.hpp>

#ifndef AUSTIN_JULIANDAY_H
#include "JulianDay.h"
#endif

#ifndef AUSTIN_DURATION_H
#include "Duration.h"
#endif

using namespace std;

class Task;
class TaskImpl;

bool operator<(const Task & lhs, const Task & rhs);
bool operator==(const Task & lhs, const Task & rhs);
bool operator!=(const Task & lhs, const Task & rhs);


class Task {
 private:
	TaskImpl * impl_;
	
 public:
	Task();
	Task(const Task & rhs);
	~Task();

	wstring		name() const;
	void		name(const wstring & value);
	void 		start(const JulianDay & value);
	JulianDay 	start();
	void 		finish(const JulianDay & value);
	JulianDay 	finish();
	void 		lateStart(const JulianDay & value);
	JulianDay 	lateStart();
	void 		lateFinish(const JulianDay & value);
	JulianDay 	lateFinish();
	Duration	work();
	void    	work(const Duration & value);
	Duration	duration();
	void 		resources(const vector<pair<wstring, double> > &); // pair(name, percent)
	vector<pair<wstring, double> > 	resources();
	double 		totalResources(); // as percent
	double 		percentComplete();
	void 		percentComplete(double percent);
	vector<wstring>	& predecessors();

	void	readConfig(DOM_Element taskElement);
	void	writeConfig(DOM_Element taskElement);

	Task & operator=(const Task & rhs);
	friend bool operator<(const Task & lhs, const Task & rhs);
	friend bool operator==(const Task & lhs, const Task & rhs);
	friend bool operator!=(const Task & lhs, const Task & rhs);
};


#endif // AUSTIN_TASK_H










